betty.test_utils.concurrent module - Betty documentation

Hide navigation sidebar
Hide table of contents sidebar
Skip to content
Back to top
View this page
Toggle table of contents sidebar

# betty.test_utils.concurrent module

Test utilities for `betty.concurrent`.

class betty.test_utils.concurrent.DummyLock

  Bases: `Lock`

  A dummy `betty.concurrent.Lock` implementation.

  __init__(acquire: bool)
  async acquire(*, wait: bool = True) → bool

    Acquire the lock.

  async release() → None

    Release the lock.